# ======================================================
# ABOUT
# ===========================
'''
GunGame-Info (Python) by PitBull (pitbull0993)

CURRENT VERSION: 0.1

GG-Info improves the GunGame5 'gameplay' a little bit.

Current improvement:
    - If a user joins, the public will get a message how many wins and which rank the user has (using the snippet/addon by Sc0pE, hope you don't mind ^^)
    - Message on Level-Up through a exlpoded bomb
    - Message when bomb has been plant. A little cheer for the user ;-)
    - Message on Level-Up through a defused bomb
    - Users on Knife-Level are a bit faster than the others
    - Give the users more ammo than normal
    - Refill the clip and the ammo on kill
'''
# ======================================================

# ======================================================
# IMPORTS
# ===========================
import es
import playerlib
import gungamelib
import ggweaponlib
# ======================================================

# ======================================================
# ADDON INFO
# ===========================
info = es.AddonInfo()
info.name     = 'GG-Info improves the GunGame-Gameplay a little bit'
info.version  = '0.1'
info.basename = 'gungame/custom_addons/gg_ip'
info.author   = 'PitBull (pitbull0993)'

es.ServerVar('gg_ip_ver', info.version).makepublic()
# ======================================================

# ======================================================
# GLOBALS
# ===========================
gg_ip_joinmessage = gungamelib.getVariableValue('gg_ip_joinmessage')
gg_ip_knife = gungamelib.getVariableValue('gg_ip_knife')
gg_ip_knife_speed = gungamelib.getVariableValue('gg_ip_knife_speed')
gg_ip_bomb_planted = gungamelib.getVariableValue('gg_ip_bomb_planted')
gg_ip_bomb_exploded = gungamelib.getVariableValue('gg_ip_bomb_exploded')
gg_ip_bomb_defused = gungamelib.getVariableValue('gg_ip_bomb_defused')
gg_ip_ammo_more = gungamelib.getVariableValue('gg_ip_ammo_more')

already_sent = []
primary = ['#all', '#primary']
secondary = ['#all', '#secondary']
# ======================================================
# LOAD/UNLOAD
# ===========================
def load():
    gg_ip = gungamelib.registerAddon('gg_ip')
    gg_ip.setDisplayName('GG-IP')
    gg_ip.loadTranslationFile()

def unload():
    gungamelib.unregisterAddon('gg_ip')
    
# ======================================================

# ======================================================
# JOIN MESSAGE
# ===========================
def player_activate(event_var):
    userid = event_var['userid']
    gungamelib.msg('gg_ip', userid, 'Advert', {'ver':info.version})
    if not gg_ip_joinmessage:
        return
    
    steamid = event_var['steamid']
    if playerCheck(userid, steamid):
        wins = gungamelib.getWins(steamid)
        rank = gungamelib.getWinnerRank(steamid)
        if not wins:
            gungamelib.msg('gg_ip', '#all', 'PlayerJoin_noRank', {'name':event_var['es_username'], 'wins':wins})
            return
        gungamelib.msg('gg_ip', '#all', 'PlayerJoin', {'name':event_var['es_username'], 'wins':wins, 'rank':rank})

def playerCheck(userid, steamid):
    userid = int(userid)
    if userid in already_sent:
        return 0
    if steamid == 'BOT':
        return 0
    already_sent.append(userid)
    return 1

def player_disconnect(event_var):
    if not gg_ip_joinmessage:
        return
    
    userid = int(event_var['userid'])
    if userid in already_sent:
        already_sent.remove(userid)

# ======================================================

# ======================================================
# KNIFE SPEED
# ===========================
def gg_levelup(event_var):
    # Check if Knife-Speed is active
    if not gg_ip_knife:
        return
    # Check if Turbo-Mode is active, otherwise the person gets the speed on a lower level
    if not gungamelib.getVariable('gg_turbo'):
        return
    # If the new weapon is not equal to knife, stop here
    if not gungamelib.getPlayer(event_var['attacker']).getWeapon() == 'knife':
        return
    
    # Get the player out of the playerlib
    player = playerlib.getPlayer(event_var['attacker'])
    # Set the speed
    player.set("speed", gg_ip_knife_speed)
    # Send a message
    gungamelib.msg('gg_ip', '#all', 'KnifeSpeed_LevelUp', {'name':player['name']})

def player_spawn(event_var):
    # Check if Knife-Speed is active
    if not gg_ip_knife:
        return

    # If the player's weapon is knife:
    if not gungamelib.getPlayer(event_var['userid']).getWeapon() == 'knife':
        return

    # Get the player out of the playerlib
    player = playerlib.getPlayer(event_var['userid'])
    # Set the speed
    player.set("speed", gg_ip_knife_speed)
    # Send a message
    gungamelib.msg('gg_ip', '#all', 'KnifeSpeed_Spawn', {'name':player['name']})

# ======================================================

# ======================================================
# BOMB MESSAGES
# ===========================
def bomb_planted(event_var):
    if gg_ip_bomb_planted:
        gungamelib.msg('gg_ip', '#all', 'Bomb_Planted', {'name':event_var['es_username']})

def bomb_exploded(event_var):
    if gg_ip_bomb_exploded:
        gungamelib.msg('gg_ip', '#all', 'Bomb_Exploded', {'name':event_var['es_username']})

def bomb_defused(event_var):
    if gg_ip_bomb_defused:
        gungamelib.msg('gg_ip', '#all', 'Bomb_Defused', {'name':event_var['es_username']})

# ======================================================

# ======================================================
# AMMO
# ===========================
def item_pickup(event_var):
    # Should we set ammo higher?
    if not gg_ip_ammo_more:
        # Stop
        return
    
    weapon = event_var['item']
    
    # Is the item a weapon that can shoot at all?
    if ggweaponlib.getWeaponInfo(weapon).get('tags') not in (primary, secondary):
        # Stop
        return
    
    # Does this weapon belong to the level?
    if weapon != gungamelib.getPlayer(event_var['userid']).getWeapon():
        # Get current weapon
        r_weapon = str(gungamelib.getPlayer(event_var['userid']).getWeapon()).upper()
        
        # Send wrong weapon message
        gungamelib.msg('gg_ip', event_var['userid'], 'Wrong_Weapon', {'w_weapon':weapon.upper(), 'r_weapon':r_weapon})
        
        # Stop
        return

    # Set the players ammo to the specified amount
    playerlib.getPlayer(event_var['userid']).set('ammo', [weapon, gg_ip_ammo_more])

def player_death(event_var):
    # Should we set the ammo higher?
    if not gg_ip_ammo_more:
        # Stop
        return
    
    # Is turbo-mode active?
    if gungamelib.getVariable('gg_turbo'):
        # Stop
        return
    
    # Is the item a weapon that can shoot at all?
    if ggweaponlib.getWeaponInfo(weapon).get('tags') not in (primary, secondary):
        # Stop
        return
    
    # Set the ammo of the player
    playerlib.getPlayer(event_var['attacker']).set('ammo', [event_var['weapon'], gg_ip_ammo_more])